[social-network-analysis](https://github.com/itsDevhere/social-network-analysis)

# Social Network Analysis Loksabha '19 Election Prediction
Social Networking Analysis  is a technique to analyse a given dataset to extract useful information and understanding the trend.
We are currently working on analyzing tweets based party name  input,analyse and plot graph for better statistical understanding and prediction purposes.
Group project of RCCIIT (Session 2015-19),Department of CSE under mentorship of Mrs.Monika Singh.

This repository will hold and be updated all the undergoing changes so far the project has experienced till now and till then.

## Steps to Install
Install :   `pip install sna_prediction`

Run Direcly as  :   `sna_prediction`

## What's done as of now

 - GUI removed for optimization purpose
 - New K-Map slider allows user to dynamically set Degree of network graph
 - Removed day-wise,month-wise graph
 - Added positive tweet per party graph
 - Added funtionality to calculate degree centrality for better prediction

## Known Issues:

 - Datasets are large,wait patiently
 - K-Map slider selected less than 3 takes longer time to render the graph due to large dataset
 
## Active Contribution

[Devpratim](https://github.com/itsDevhere "https://github.com/itsDevhere")

[Rana](https://github.com/RanaMondal03 "https://github.com/RanaMondal03")

[Souvik](https://github.com/Souvik08 "https://github.com/Souvik08")

Soumjit


## Snapshots:
[Program Output](https://imgur.com/a/fNTlOoS) 

[+ve and -ve tweets per party](https://imgur.com/a/HUji90k)